fernet_object

Function fernet_object 

pub fn fernet_object() -> Arc<Fernet> 
Create a Fernet object to encrypt and decrypt session token.

Generates a random key, that can be safely passed to Fernet::new()

Returns

Returns the constructed Arc for the Fernet instance, with the generated key.