pub struct logout;Expand description
Handles the logout endpoint, logging out the user and rendering the appropriate HTML page.
Arguments
request- A reference to the Actix webHttpRequestobject.config- Configuration data for the application.fernet- Fernet object to encrypt the auth payload that will be set assession_tokencookie.template- Configuration container for the loaded templates.session- Session struct that holds thesession_mappingandsession_trackerto handle sessions.
Returns
Returns an HTTPResponse with the cookie for session_token reset if available.