Module media

Module media 

Module for all the rendering based entry points.

Structs

Payload
Represents the payload structure for deserializing data from the request query parameters.
Subtitles ๐Ÿ”’
Represents the paths and filenames for subtitles, including both SRT and VTT formats.
stream
Handles requests for the /stream/{media_path:.*} endpoint, serving media files and directories.
streaming_endpoint
Handles requests for the /media endpoint, serving media content for streaming.
track
Handles requests for the โ€˜/track/{track_path:.*}โ€™ endpoint, serving track files.

Functions

render_content ๐Ÿ”’
Create an HttpResponse based on the context built and rendered template.
subtitles ๐Ÿ”’
Constructs a Subtitles struct based on the provided target path and target_str.
url_encode ๐Ÿ”’
URL encodes the provided path string.