Struct rustream::routes::upload::save_files
source · pub struct save_files;Expand description
Saves files locally by breaking them into chunks.
Arguments
request- A reference to the Actix webHttpRequestobject.payload- Mutable multipart struct that is sent from the UI asFormData.fernet- Fernet object to encrypt the auth payload that will be set assession_tokencookie.session- Session struct that holds thesession_mappingandsession_trackerto handle sessions.config- Configuration data for the application.
References
Returns
200- Plain HTTPResponse indicating that the file was uploaded.422- HTTPResponse with JSON object indicating that the payload was incomplete.400- HTTPResponse with JSON object indicating that the payload was invalid.