Module authenticator

Module authenticator 

Module that handles the authentication and

Structs

AuthToken
Represents the result of authentication, indicating whether it was successful or not.
Credentials 🔒
Represents user credentials extracted from an authorization header.

Functions

extract_credentials 🔒
Extracts credentials from the authorization header in the following steps
verify_login
Verifies user login based on extracted credentials and configuration settings.
verify_secure_index
Verifies the secure index of the directory/file that’s being accessed.
verify_token
Verifies a session token extracted from an HTTP request against stored session mappings and configuration.