pub fn get_config(cargo: &Cargo) -> Arc<Config>
Retrieves the environment variables and parses as the data-type specified in Config struct.
Arguments
cargo - Package specific information loaded in a struct.
Returns
Converts the config struct into an Arc and returns it.