Module rustream::templates

source ·
Module to load all the templates for the UI.

Modules

  • error 🔒
    Error page template that is served as HTML response for any error message to be conveyed.
  • index 🔒
    Index page template that is served as HTML response for the root endpoint.
  • landing 🔒
    Landing page template that is served as HTML response while streaming media.
  • listing 🔒
    Listing page template that is served as HTML response after successful authentication.
  • logout 🔒
    Logout page template that is served as HTML response when the user decides to end the session.
  • session 🔒
    Session page template that is served as HTML response when invalid/expired session tokens are received.
  • upload 🔒

Functions

  • Loads all the HTML templates’ content into a Jinja Environment