Module for all the rendering based entry points.
Structs
- Payload
- Represents the payload structure for deserializing data from the request query parameters.
- Subtitles ๐
- Represents the paths and filenames for subtitles, including both SRT and VTT formats.
- stream
- Handles requests for the
/stream/{media_path:.*}endpoint, serving media files and directories. - streaming_
endpoint - Handles requests for the
/mediaendpoint, serving media content for streaming. - track
- Handles requests for the โ/track/{track_path:.*}โ endpoint, serving track files.
Functions
- render_
content ๐ - Create an
HttpResponsebased on the context built and rendered template. - subtitles ๐
- Constructs a
Subtitlesstruct based on the providedtargetpath andtarget_str. - url_
encode ๐ - URL encodes the provided path string.